#!/bin/bash

## 	name: 		runRelaxWorker.sh
## 	purpose:	run BBQ and Relax and send results back to
##                      the calling node
##	author:		Kevin Molloy
##	date:		January 2014

##	NOTES:
##	-----

if [ $# -ne 4 ]
then
usage: runRelaxWorker.sh INPUT_PDB OUTPUT_PDB DELETE_PREFIX SOFTWARE_DIR
exit 99
fi

INPUT_PDB=${1}
OUTPUT_PDB=${2}
DELETE_FILE_PREFIX=${3}

SOFTWARE_DIR=${4}

VARFILE=${SOFTWARE_DIR}/relaxCoordinatorVars.sh
if [ ! -x ${VARFILE} ]
then
  echo Could not find varfile or wrong perms:${VARFILE}
  exit 99
fi

. ${SOFTWARE_DIR}/relaxCoordinatorVars.sh

echo Input PDB is ${INPUT_PDB}
echo Output PDB is ${OUTPUT_PDB}
echo Delete prefix is ${DELETE_FILE_PREFIX}

## Step 1 -- make a directory for us to perform the relax in

WORK_DIR=${DELETE_FILE_PREFIX}.$$

mkdir ${WORK_DIR}
if [ ! -d ${WORK_DIR} ]
then
  echo Failed to make ${WORK_DIR}  Aborting
  exit 99
fi

cd ${WORK_DIR}
WORK_DIR=$(pwd)

## BBQ it

echo running BBQ

BBQ_OUTPUT=${INPUT_PDB}_bbq
echo ${JAVA} -classpath ${BBQ_DIR}:${BBQ_JAR}  BBQ -d=${BBQ_DIR}/q_50_xyz.dat \
     -r=${INPUT_PDB} #> ${BBQ_OUTPUT}


${JAVA} -classpath ${BBQ_DIR}:${BBQ_JAR}  BBQ -d=${BBQ_DIR}/q_50_xyz.dat \
     -r=${INPUT_PDB} > ${BBQ_OUTPUT}
echo done with BBQ, running rosetta

if [ ! -f ${BBQ_OUTPUT} ]
then
  echo BBQ output file does not exist
  exit 99
else
  echo BBQ file exists ${BBQ_OUTPUT}
  rm ${INPUT_PDB}
fi


echo starting Rosetta `date`
${RELAX_EXE} -database ${ROSETTA_DB} \
   -in:file:fullatom \
   -in:file:s ${INPUT_PDB}_bbq \
   -relax:script ${SOFTWARE_DIR}/rosetta_relax.cmd \
   -relax:quick \
   -ignore_zero_occupancy false \
   -relax:constrain_relax_to_start_coords > relax.rpt 2>&1
rosetta_rc=$?

## remove BBQ file now
rm ${INPUT_PDB}_bbq

echo Rosetta complete rc is ${rosetta_rc} at `date`

BN=`basename ${INPUT_PDB} .pdb`

START_FILE=${DELETE_FILE_PREFIX}.pdb.start

cp ${BN}_0001.pdb ${OUTPUT_PDB}

rm ${DELETE_FILE_PREFIX}.working

touch ${DELETE_FILE_PREFIX}.done

cd ${SOFTWARE_DIR}
if [ -d ${WORK_DIR} ]
then
  rm -r ${WORK_DIR}
fi

exit 0
